Struct SharedUnitData

pub(crate) struct SharedUnitData {
    pub name: CapeStringImpl,
    pub validation_status: CapeValidationStatus,
    pub dirty: bool,
}
The SharedUnitData struct holds common data for the distillation shortcut unit.

Each distillation shortcut unit contains a single instance of SharedUnitData that holds information such as the unit’s name and validation status. This data is shared across all components of the unit, including ports, collections, and parameters.

Fields

name: CapeStringImpl

The name of the distillation shortcut unit; used by various components for formatting the error source name.

validation_status: CapeValidationStatus

The validation status of the distillation shortcut unit; used by various components to flag the unit as not validated.

dirty: bool